==> oci-2.23.4.tar.gz: oci-2.23.4/src/oci/core/models/public_ip_pool_collection.py <==
# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class PublicIpPoolCollection(object):
    """
    Results of a ListPublicIpPool operation.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new PublicIpPoolCollection object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param items:
            The value to assign to the items property of this PublicIpPoolCollection.
        :type items: list[PublicIpPoolSummary]

        """
        self.swagger_types = {
            'items': 'list[PublicIpPoolSummary]'
        }

        self.attribute_map = {
            'items': 'items'
        }

        self._items = None

    @property
    def items(self):
        """
        **[Required]** Gets the items of this PublicIpPoolCollection.
        list of Public Ip pool object summaries


        :return: The items of this PublicIpPoolCollection.
        :rtype: list[PublicIpPoolSummary]
        """
        return self._items

    @items.setter
    def items(self, items):
        """
        Sets the items of this PublicIpPoolCollection.
        list of Public Ip pool object summaries


        :param items: The items of this PublicIpPoolCollection.
        :type: list[PublicIpPoolSummary]
        """
        self._items = items

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other

==> oci-2.52.1.tar.gz: oci-2.52.1/src/oci/core/models/public_ip_pool_collection.py <==
# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class PublicIpPoolCollection(object):
    """
    Results of a `ListPublicIpPool` operation.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new PublicIpPoolCollection object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param items:
            The value to assign to the items property of this PublicIpPoolCollection.
        :type items: list[oci.core.models.PublicIpPoolSummary]

        """
        self.swagger_types = {
            'items': 'list[PublicIpPoolSummary]'
        }

        self.attribute_map = {
            'items': 'items'
        }

        self._items = None

    @property
    def items(self):
        """
        **[Required]** Gets the items of this PublicIpPoolCollection.
        A list of public IP pool summaries.


        :return: The items of this PublicIpPoolCollection.
        :rtype: list[oci.core.models.PublicIpPoolSummary]
        """
        return self._items

    @items.setter
    def items(self, items):
        """
        Sets the items of this PublicIpPoolCollection.
        A list of public IP pool summaries.


        :param items: The items of this PublicIpPoolCollection.
        :type: list[oci.core.models.PublicIpPoolSummary]
        """
        self._items = items

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
